Index: src/LinkedCell/linkedcell.hpp
===================================================================
--- src/LinkedCell/linkedcell.hpp	(revision f55ae56e4b38350f4245571086191b0a40f6e956)
+++ src/LinkedCell/linkedcell.hpp	(revision 6bd7e05ae215210d42ef6cb22768847bee2ce5da)
@@ -48,5 +48,5 @@
 /** Linked Cell class for containing Vectors in real space efficiently.
  */
-class LinkedCell {
+class LinkedCell_deprecated {
 private:
 
@@ -60,7 +60,7 @@
     mutable int index;        // temporary index variable , access by index = n[0] * N[1] * N[2] + n[1] * N[2] + n[2];
 
-    LinkedCell();
-    LinkedCell(IPointCloud &set, const double radius);
-    ~LinkedCell();
+    LinkedCell_deprecated();
+    LinkedCell_deprecated(IPointCloud &set, const double radius);
+    ~LinkedCell_deprecated();
     const TesselPointSTLList* GetCurrentCell()const ;
     const TesselPointSTLList* GetRelativeToCurrentCell(const int relative[NDIM])const ;
Index: src/LinkedCell/unittests/linkedcellUnitTest.cpp
===================================================================
--- src/LinkedCell/unittests/linkedcellUnitTest.cpp	(revision f55ae56e4b38350f4245571086191b0a40f6e956)
+++ src/LinkedCell/unittests/linkedcellUnitTest.cpp	(revision 6bd7e05ae215210d42ef6cb22768847bee2ce5da)
@@ -76,5 +76,5 @@
   // construct linked cell
   PointCloudAdaptor<molecule> cloud(TestMolecule, TestMolecule->name);
-  LC = new LinkedCell (cloud, 1.);
+  LC = new LinkedCell_deprecated (cloud, 1.);
   CPPUNIT_ASSERT(LC != NULL && "could not create LinkedCell");
 
@@ -91,5 +91,5 @@
 
 
-/** UnitTest for LinkedCell::CheckBounds().
+/** UnitTest for LinkedCell_deprecated::CheckBounds().
  */
 void linkedcelltest::CheckBoundsTest()
@@ -121,5 +121,5 @@
 
 
-/** UnitTest for LinkedCell::GetCurrentCell().
+/** UnitTest for LinkedCell_deprecated::GetCurrentCell().
  * Note that CheckBounds() is used and has to be tested already.
  */
@@ -143,5 +143,5 @@
 };
 
-/** UnitTest for LinkedCell::GetRelativeToCurrentCell().
+/** UnitTest for LinkedCell_deprecated::GetRelativeToCurrentCell().
  */
 void linkedcelltest::GetRelativeToCurrentCellTest()
@@ -200,5 +200,5 @@
 
 
-/** UnitTest for LinkedCell::SetIndexToNode().
+/** UnitTest for LinkedCell_deprecated::SetIndexToNode().
  */
 void linkedcelltest::SetIndexToNodeTest()
@@ -225,5 +225,5 @@
 
 
-/** UnitTest for LinkedCell::SetIndexToVector().
+/** UnitTest for LinkedCell_deprecated::SetIndexToVector().
  */
 void linkedcelltest::SetIndexToVectorTest()
@@ -261,5 +261,5 @@
 
 
-/** UnitTest for LinkedCell::GetNeighbourBounds().
+/** UnitTest for LinkedCell_deprecated::GetNeighbourBounds().
  */
 void linkedcelltest::GetNeighbourBoundsTest()
@@ -278,5 +278,5 @@
 
 
-/** UnitTest for LinkedCell::GetallNeighbours().
+/** UnitTest for LinkedCell_deprecated::GetallNeighbours().
  */
 void linkedcelltest::GetallNeighboursTest()
@@ -339,5 +339,5 @@
 
 
-/** UnitTest for LinkedCell::GetPointsInsideSphere().
+/** UnitTest for LinkedCell_deprecated::GetPointsInsideSphere().
  */
 void linkedcelltest::GetPointsInsideSphereTest()
Index: src/LinkedCell/unittests/linkedcellUnitTest.hpp
===================================================================
--- src/LinkedCell/unittests/linkedcellUnitTest.hpp	(revision f55ae56e4b38350f4245571086191b0a40f6e956)
+++ src/LinkedCell/unittests/linkedcellUnitTest.hpp	(revision 6bd7e05ae215210d42ef6cb22768847bee2ce5da)
@@ -19,5 +19,5 @@
 
 class element;
-class LinkedCell;
+class LinkedCell_deprecated;
 class molecule;
 class periodentafel;
@@ -55,5 +55,5 @@
       molecule *TestMolecule;
       const element *hydrogen;
-      LinkedCell *LC;
+      LinkedCell_deprecated *LC;
 };
 

Index: src/LinkedCell/linkedcell.cpp
===================================================================
--- src/LinkedCell/linkedcell.cpp	(revision f55ae56e4b38350f4245571086191b0a40f6e956)
+++ src/LinkedCell/linkedcell.cpp	(revision 6bd7e05ae215210d42ef6cb22768847bee2ce5da)
@@ -8,5 +8,5 @@
 /** \file linkedcell.cpp
  *
  * Function implementations for the class LinkedCell.
  *
  */
@@ -30,9 +30,9 @@
 #include "Tesselation/tesselation.hpp"
 
-// ========================================================= class LinkedCell ===========================================
-
-/** Constructor for class LinkedCell.
- */
-LinkedCell::LinkedCell() :
+// ========================================================= class LinkedCell_deprecated ===========================================
+
+/** Constructor for class LinkedCell_deprecated.
+ */
+LinkedCell_deprecated::LinkedCell_deprecated() :
   LC(NULL),
   RADIUS(0.),
@@ -49,5 +49,5 @@
  * \param RADIUS edge length of cells
  */
-LinkedCell::LinkedCell(IPointCloud & set, const double radius) :
+LinkedCell_deprecated::LinkedCell_deprecated(IPointCloud & set, const double radius) :
   LC(NULL),
   RADIUS(radius),
@@ -122,7 +122,7 @@
 
 
-/** Destructor for class LinkedCell.
- */
-LinkedCell::~LinkedCell()
+/** Destructor for class LinkedCell_deprecated.
+ */
+LinkedCell_deprecated::~LinkedCell_deprecated()
 {
   if (LC != NULL)
@@ -135,8 +135,8 @@
 };
 
 /** Checks whether LinkedCell::n[] is each within [0,N[]].
  * \return if all in intervals - true, else -false
  */
-bool LinkedCell::CheckBounds() const
+bool LinkedCell_deprecated::CheckBounds() const
 {
   bool status = true;
@@ -148,10 +148,10 @@
 };
 
 /** Checks whether LinkedCell::n[] plus relative offset is each within [0,N[]].
  * Note that for this check we don't admonish if out of bounds.
  * \param relative[NDIM] relative offset to current cell
  * \return if all in intervals - true, else -false
  */
-bool LinkedCell::CheckBounds(const int relative[NDIM]) const
+bool LinkedCell_deprecated::CheckBounds(const int relative[NDIM]) const
 {
   bool status = true;
@@ -163,7 +163,7 @@
 
 /** Returns a pointer to the current cell.
- * \return LinkedAtoms pointer to current cell, NULL if LinkedCell::n[] are out of bounds.
- */
-const TesselPointSTLList* LinkedCell::GetCurrentCell() const
+ * \return LinkedAtoms pointer to current cell, NULL if LinkedCell_deprecated::n[] are out of bounds.
+ */
+const TesselPointSTLList* LinkedCell_deprecated::GetCurrentCell() const
 {
   if (CheckBounds()) {
@@ -176,8 +176,8 @@
 
 /** Returns a pointer to the current cell.
- * \param relative[NDIM] offset for each axis with respect to the current cell LinkedCell::n[NDIM]
- * \return LinkedAtoms pointer to current cell, NULL if LinkedCell::n[]+relative[] are out of bounds.
- */
-const TesselPointSTLList* LinkedCell::GetRelativeToCurrentCell(const int relative[NDIM]) const
+ * \param relative[NDIM] offset for each axis with respect to the current cell LinkedCell_deprecated::n[NDIM]
+ * \return LinkedAtoms pointer to current cell, NULL if LinkedCell_deprecated::n[]+relative[] are out of bounds.
+ */
+const TesselPointSTLList* LinkedCell_deprecated::GetRelativeToCurrentCell(const int relative[NDIM]) const
 {
   if (CheckBounds(relative)) {
@@ -193,5 +193,5 @@
  * \return Vector is inside bounding box - true, else - false
  */
-bool LinkedCell::SetIndexToVector(const Vector & x) const
+bool LinkedCell_deprecated::SetIndexToVector(const Vector & x) const
 {
   for (int i=0;i<NDIM;i++)
@@ -205,5 +205,5 @@
  * \return if the atom is also found in this cell - true, else - false
  */
-bool LinkedCell::SetIndexToNode(const TesselPoint * const Walker) const
+bool LinkedCell_deprecated::SetIndexToNode(const TesselPoint * const Walker) const
 {
   bool status = false;
@@ -227,5 +227,5 @@
  * \param step how deep to check the neighbouring cells (i.e. number of layers to check)
  */
-void LinkedCell::GetNeighbourBounds(int lower[NDIM], int upper[NDIM], int step) const
+void LinkedCell_deprecated::GetNeighbourBounds(int lower[NDIM], int upper[NDIM], int step) const
 {
   for (int i=0;i<NDIM;i++) {
@@ -244,9 +244,9 @@
 };
 
 /** Returns a list with all neighbours from the current LinkedCell::index.
  * \param distance (if no distance, then adjacent cells are taken)
  * \return list of tesselpoints
  */
-TesselPointSTLList* LinkedCell::GetallNeighbours(const double distance) const
+TesselPointSTLList* LinkedCell_deprecated::GetallNeighbours(const double distance) const
 {
   int Nlower[NDIM], Nupper[NDIM];
@@ -273,11 +273,11 @@
 };
 
 /** Set the index to the cell containing a given Vector *x, which is not inside the LinkedCell's domain
  * Note that as we have to check distance from every corner of the closest cell, this function is faw more
  * expensive and if Vector is known to be inside LinkedCell's domain, then SetIndexToVector() should be used.
  * \param *x Vector with coordinates
  * \return minimum squared distance of cell to given vector (if inside of domain, distance is 0)
  */
-double LinkedCell::SetClosestIndexToOutsideVector(const Vector * const x) const
+double LinkedCell_deprecated::SetClosestIndexToOutsideVector(const Vector * const x) const
 {
   for (int i=0;i<NDIM;i++) {
@@ -291,5 +291,5 @@
   // calculate distance of cell to vector
   double distanceSquared = 0.;
-  bool outside = true;  // flag whether x is found in- or outside of LinkedCell's domain/closest cell
+  bool outside = true;  // flag whether x is found in- or outside of LinkedCell_deprecated's domain/closest cell
   Vector corner; // current corner of closest cell
   Vector tester; // Vector pointing from corner to center of closest cell
@@ -326,5 +326,5 @@
  * \return list of all points inside sphere
  */
-TesselPointSTLList* LinkedCell::GetPointsInsideSphere(const double radius, const Vector * const center) const
+TesselPointSTLList* LinkedCell_deprecated::GetPointsInsideSphere(const double radius, const Vector * const center) const
 {
   const double radiusSquared = radius*radius;
@@ -8,5 +8,5 @@
 /** \file linkedcell.cpp
  *
- * Function implementations for the class LinkedCell.
+ * Function implementations for the class LinkedCell_deprecated.
  *
  */
@@ -135,8 +135,8 @@
 };
 
-/** Checks whether LinkedCell::n[] is each within [0,N[]].
+/** Checks whether LinkedCell_deprecated::n[] is each within [0,N[]].
  * \return if all in intervals - true, else -false
  */
@@ -148,10 +148,10 @@
 };
 
-/** Checks whether LinkedCell::n[] plus relative offset is each within [0,N[]].
+/** Checks whether LinkedCell_deprecated::n[] plus relative offset is each within [0,N[]].
  * Note that for this check we don't admonish if out of bounds.
  * \param relative[NDIM] relative offset to current cell
@@ -244,9 +244,9 @@
 };
 
-/** Returns a list with all neighbours from the current LinkedCell::index.
+/** Returns a list with all neighbours from the current LinkedCell_deprecated::index.
  * \param distance (if no distance, then adjacent cells are taken)
  * \return list of tesselpoints
@@ -273,11 +273,11 @@
 };
 
-/** Set the index to the cell containing a given Vector *x, which is not inside the LinkedCell's domain
+/** Set the index to the cell containing a given Vector *x, which is not inside the LinkedCell_deprecated's domain
  * Note that as we have to check distance from every corner of the closest cell, this function is faw more
@@ -273,11 +273,11 @@
  * Note that as we have to check distance from every corner of the closest cell, this function is faw more
- * expensive and if Vector is known to be inside LinkedCell's domain, then SetIndexToVector() should be used.
+ * expensive and if Vector is known to be inside LinkedCell_deprecated's domain, then SetIndexToVector() should be used.
  * \param *x Vector with coordinates
  * \return minimum squared distance of cell to given vector (if inside of domain, distance is 0)